/****************************************************************************
** Meta object code from reading C++ file 'variablesWidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kcron-17.04.3/src/variablesWidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'variablesWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_VariablesWidget_t {
    QByteArrayData data[13];
    char stringdata0[168];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_VariablesWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_VariablesWidget_t qt_meta_stringdata_VariablesWidget = {
    {
QT_MOC_LITERAL(0, 0, 15), // "VariablesWidget"
QT_MOC_LITERAL(1, 16, 16), // "variableModified"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 15), // "modifySelection"
QT_MOC_LITERAL(4, 50, 15), // "deleteSelection"
QT_MOC_LITERAL(5, 66, 14), // "createVariable"
QT_MOC_LITERAL(6, 81, 11), // "addVariable"
QT_MOC_LITERAL(7, 93, 11), // "CTVariable*"
QT_MOC_LITERAL(8, 105, 8), // "variable"
QT_MOC_LITERAL(9, 114, 22), // "changeCurrentSelection"
QT_MOC_LITERAL(10, 137, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(11, 154, 4), // "item"
QT_MOC_LITERAL(12, 159, 8) // "position"

    },
    "VariablesWidget\0variableModified\0\0"
    "modifySelection\0deleteSelection\0"
    "createVariable\0addVariable\0CTVariable*\0"
    "variable\0changeCurrentSelection\0"
    "QTreeWidgetItem*\0item\0position"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_VariablesWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   52,    2, 0x0a /* Public */,
       4,    0,   53,    2, 0x0a /* Public */,
       5,    0,   54,    2, 0x0a /* Public */,
       6,    1,   55,    2, 0x0a /* Public */,
       9,    0,   58,    2, 0x0a /* Public */,
       3,    2,   59,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 10, QMetaType::Int,   11,   12,

       0        // eod
};

void VariablesWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        VariablesWidget *_t = static_cast<VariablesWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->variableModified((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->modifySelection(); break;
        case 2: _t->deleteSelection(); break;
        case 3: _t->createVariable(); break;
        case 4: _t->addVariable((*reinterpret_cast< CTVariable*(*)>(_a[1]))); break;
        case 5: _t->changeCurrentSelection(); break;
        case 6: _t->modifySelection((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (VariablesWidget::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&VariablesWidget::variableModified)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject VariablesWidget::staticMetaObject = {
    { &GenericListWidget::staticMetaObject, qt_meta_stringdata_VariablesWidget.data,
      qt_meta_data_VariablesWidget,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *VariablesWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VariablesWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_VariablesWidget.stringdata0))
        return static_cast<void*>(const_cast< VariablesWidget*>(this));
    return GenericListWidget::qt_metacast(_clname);
}

int VariablesWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GenericListWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void VariablesWidget::variableModified(bool _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_END_MOC_NAMESPACE
