/****************************************************************************
** Meta object code from reading C++ file 'variableEditorDialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kcron-17.04.3/src/variableEditorDialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'variableEditorDialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_VariableEditorDialog_t {
    QByteArrayData data[8];
    char stringdata0[103];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_VariableEditorDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_VariableEditorDialog_t qt_meta_stringdata_VariableEditorDialog = {
    {
QT_MOC_LITERAL(0, 0, 20), // "VariableEditorDialog"
QT_MOC_LITERAL(1, 21, 16), // "setupTitleWidget"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 7), // "comment"
QT_MOC_LITERAL(4, 47, 25), // "KTitleWidget::MessageType"
QT_MOC_LITERAL(5, 73, 11), // "slotEnabled"
QT_MOC_LITERAL(6, 85, 6), // "slotOk"
QT_MOC_LITERAL(7, 92, 10) // "slotWizard"

    },
    "VariableEditorDialog\0setupTitleWidget\0"
    "\0comment\0KTitleWidget::MessageType\0"
    "slotEnabled\0slotOk\0slotWizard"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_VariableEditorDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   44,    2, 0x08 /* Private */,
       1,    1,   49,    2, 0x28 /* Private | MethodCloned */,
       1,    0,   52,    2, 0x28 /* Private | MethodCloned */,
       5,    0,   53,    2, 0x08 /* Private */,
       6,    0,   54,    2, 0x08 /* Private */,
       7,    0,   55,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString, 0x80000000 | 4,    3,    2,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void VariableEditorDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        VariableEditorDialog *_t = static_cast<VariableEditorDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->setupTitleWidget((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< KTitleWidget::MessageType(*)>(_a[2]))); break;
        case 1: _t->setupTitleWidget((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->setupTitleWidget(); break;
        case 3: _t->slotEnabled(); break;
        case 4: _t->slotOk(); break;
        case 5: _t->slotWizard(); break;
        default: ;
        }
    }
}

const QMetaObject VariableEditorDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_VariableEditorDialog.data,
      qt_meta_data_VariableEditorDialog,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *VariableEditorDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VariableEditorDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_VariableEditorDialog.stringdata0))
        return static_cast<void*>(const_cast< VariableEditorDialog*>(this));
    return QDialog::qt_metacast(_clname);
}

int VariableEditorDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
