/****************************************************************************
** Meta object code from reading C++ file 'taskEditorDialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kcron-17.04.3/src/taskEditorDialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'taskEditorDialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_TaskEditorDialog_t {
    QByteArrayData data[21];
    char stringdata0[329];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TaskEditorDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TaskEditorDialog_t qt_meta_stringdata_TaskEditorDialog = {
    {
QT_MOC_LITERAL(0, 0, 16), // "TaskEditorDialog"
QT_MOC_LITERAL(1, 17, 16), // "setupTitleWidget"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 7), // "comment"
QT_MOC_LITERAL(4, 43, 25), // "KTitleWidget::MessageType"
QT_MOC_LITERAL(5, 69, 18), // "slotEnabledChanged"
QT_MOC_LITERAL(6, 88, 17), // "slotRebootChanged"
QT_MOC_LITERAL(7, 106, 16), // "slotDailyChanged"
QT_MOC_LITERAL(8, 123, 6), // "slotOK"
QT_MOC_LITERAL(9, 130, 10), // "slotWizard"
QT_MOC_LITERAL(10, 141, 13), // "slotAllMonths"
QT_MOC_LITERAL(11, 155, 16), // "slotMonthChanged"
QT_MOC_LITERAL(12, 172, 18), // "slotAllDaysOfMonth"
QT_MOC_LITERAL(13, 191, 21), // "slotDayOfMonthChanged"
QT_MOC_LITERAL(14, 213, 17), // "slotAllDaysOfWeek"
QT_MOC_LITERAL(15, 231, 20), // "slotDayOfWeekChanged"
QT_MOC_LITERAL(16, 252, 12), // "slotAllHours"
QT_MOC_LITERAL(17, 265, 15), // "slotHourChanged"
QT_MOC_LITERAL(18, 281, 23), // "slotMinutesPreselection"
QT_MOC_LITERAL(19, 305, 5), // "index"
QT_MOC_LITERAL(20, 311, 17) // "slotMinuteChanged"

    },
    "TaskEditorDialog\0setupTitleWidget\0\0"
    "comment\0KTitleWidget::MessageType\0"
    "slotEnabledChanged\0slotRebootChanged\0"
    "slotDailyChanged\0slotOK\0slotWizard\0"
    "slotAllMonths\0slotMonthChanged\0"
    "slotAllDaysOfMonth\0slotDayOfMonthChanged\0"
    "slotAllDaysOfWeek\0slotDayOfWeekChanged\0"
    "slotAllHours\0slotHourChanged\0"
    "slotMinutesPreselection\0index\0"
    "slotMinuteChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TaskEditorDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      18,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,  104,    2, 0x08 /* Private */,
       1,    1,  109,    2, 0x28 /* Private | MethodCloned */,
       1,    0,  112,    2, 0x28 /* Private | MethodCloned */,
       5,    0,  113,    2, 0x08 /* Private */,
       6,    0,  114,    2, 0x08 /* Private */,
       7,    0,  115,    2, 0x08 /* Private */,
       8,    0,  116,    2, 0x08 /* Private */,
       9,    0,  117,    2, 0x08 /* Private */,
      10,    0,  118,    2, 0x08 /* Private */,
      11,    0,  119,    2, 0x08 /* Private */,
      12,    0,  120,    2, 0x08 /* Private */,
      13,    0,  121,    2, 0x08 /* Private */,
      14,    0,  122,    2, 0x08 /* Private */,
      15,    0,  123,    2, 0x08 /* Private */,
      16,    0,  124,    2, 0x08 /* Private */,
      17,    0,  125,    2, 0x08 /* Private */,
      18,    1,  126,    2, 0x08 /* Private */,
      20,    0,  129,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString, 0x80000000 | 4,    3,    2,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   19,
    QMetaType::Void,

       0        // eod
};

void TaskEditorDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TaskEditorDialog *_t = static_cast<TaskEditorDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->setupTitleWidget((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< KTitleWidget::MessageType(*)>(_a[2]))); break;
        case 1: _t->setupTitleWidget((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->setupTitleWidget(); break;
        case 3: _t->slotEnabledChanged(); break;
        case 4: _t->slotRebootChanged(); break;
        case 5: _t->slotDailyChanged(); break;
        case 6: _t->slotOK(); break;
        case 7: _t->slotWizard(); break;
        case 8: _t->slotAllMonths(); break;
        case 9: _t->slotMonthChanged(); break;
        case 10: _t->slotAllDaysOfMonth(); break;
        case 11: _t->slotDayOfMonthChanged(); break;
        case 12: _t->slotAllDaysOfWeek(); break;
        case 13: _t->slotDayOfWeekChanged(); break;
        case 14: _t->slotAllHours(); break;
        case 15: _t->slotHourChanged(); break;
        case 16: _t->slotMinutesPreselection((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->slotMinuteChanged(); break;
        default: ;
        }
    }
}

const QMetaObject TaskEditorDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_TaskEditorDialog.data,
      qt_meta_data_TaskEditorDialog,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *TaskEditorDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TaskEditorDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_TaskEditorDialog.stringdata0))
        return static_cast<void*>(const_cast< TaskEditorDialog*>(this));
    return QDialog::qt_metacast(_clname);
}

int TaskEditorDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 18;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
